// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
"use strict";
var semver_1 = require('semver');
/**
 * A cache using semver ranges to retrieve values.
 */
var SemVerCache = (function () {
    function SemVerCache() {
        this._cache = Object.create(null);
    }
    SemVerCache.prototype.set = function (key, version, object) {
        if (!(key in this._cache)) {
            this._cache[key] = Object.create(null);
        }
        if (!(version in this._cache[key])) {
            this._cache[key][version] = object;
        }
    };
    SemVerCache.prototype.get = function (key, semver) {
        if (key in this._cache) {
            var versions = this._cache[key];
            var best = semver_1.maxSatisfying(Object.keys(versions), semver);
            return versions[best];
        }
    };
    return SemVerCache;
}());
exports.SemVerCache = SemVerCache;
